@@ -46,6 +46,7 @@
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
+#include <QDBusConnection>
 #include <QIcon>
 #include <QLabel>
 #include <QSplitter>
@@ -75,17 +76,17 @@ static const char Description[] = I18N_NOOP( "KDE System Monitor" );
 TopLevel* Toplevel;
 
 TopLevel::TopLevel()
-  : KXmlGuiWindow( NULL, Qt::WindowFlags(KDE_DEFAULT_WINDOWFLAGS) | Qt::WindowContextHelpButtonHint)
+  : KXmlGuiWindow( nullptr, Qt::WindowFlags(KDE_DEFAULT_WINDOWFLAGS) | Qt::WindowContextHelpButtonHint)
 {
   QDBusConnection::sessionBus().registerObject(QStringLiteral("/"), this, QDBusConnection::ExportScriptableSlots);
   mTimerId = -1;
-  mLocalProcessController = NULL;
+  mLocalProcessController = nullptr;
 
   mSplitter = new QSplitter( this );
   mSplitter->setOrientation( Qt::Horizontal );
   setCentralWidget( mSplitter );
 
-  mSensorBrowser = 0;
+  mSensorBrowser = nullptr;
 
   mWorkSpace = new Workspace( mSplitter );
   connect( mWorkSpace, SIGNAL(setCaption(QString)),
@@ -137,7 +138,7 @@ TopLevel::TopLevel()
   mHotNewWorksheetUploadAction->setIcon( QIcon::fromTheme(QStringLiteral("network-server")) );
   connect(mHotNewWorksheetUploadAction, &QAction::triggered, mWorkSpace, &Workspace::uploadHotNewWorksheet);
 
-  mQuitAction = NULL;
+  mQuitAction = nullptr;
 
   mConfigureSheetAction = actionCollection()->addAction( QStringLiteral("configure_sheet") );
   mConfigureSheetAction->setIcon( QIcon::fromTheme(QStringLiteral("configure")) );
@@ -170,7 +171,7 @@ void TopLevel::retranslateUi()
 
   mConfigureSheetAction->setText( i18n( "Tab &Properties" ) );
   if(mQuitAction) {
-    QAction *tmpQuitAction = KStandardAction::quit( NULL, NULL, NULL );
+    QAction *tmpQuitAction = KStandardAction::quit( nullptr, nullptr, nullptr );
     mQuitAction->setText(tmpQuitAction->text());
     mQuitAction->setWhatsThis(tmpQuitAction->whatsThis());
     mQuitAction->setToolTip(tmpQuitAction->toolTip());
@@ -363,7 +364,8 @@ void TopLevel::timerEvent( QTimerEvent* )
 }
 
 void TopLevel::updateProcessCount()  {
-    const QString s = i18np( "1 process" "\u009C" "1", "%1 processes" "\u009C" "%1", mLocalProcessController->processList()->visibleProcessesCount() );
+    const int count = mLocalProcessController->processList()->visibleProcessesCount();
+    const QString s = i18np( "1 process", "%1 processes", count ) + "\xc2\x9c" + QString::number( count );
     sbProcessCount->setText( s );
 }
 void TopLevel::changeEvent( QEvent * event )
@@ -442,9 +444,12 @@ void TopLevel::answerReceived( int id, const QList<QByteArray> &answerList )
 
   switch ( id ) {
     case 1:
-      s = i18n( "CPU: %1%\xc2\x9c%1%", (int) (100 - answer.toFloat()) );
+    {
+      const auto percent = (int) (100 - answer.toFloat());
+      s = i18n( "CPU: %1%", percent ) + "\xc2\x9c" + i18nc("This is the shorter version of CPU: %1%", "%1%", percent);
       sbCpuStat->setText( s );
       break;
+    }
 
     case 2:
       mFree = answer.toLongLong();
@@ -455,13 +460,21 @@ void TopLevel::answerReceived( int id, const QList<QByteArray> &answerList )
       break;
 
     case 4:
+    {
+      const auto used = KFormat().formatByteSize( mUsedApplication*1024);
+      const auto total = KFormat().formatByteSize( (mFree+mUsedTotal)*1024 );
       mUsedApplication = answer.toLongLong();
       //Use a multi-length string
-      s = i18nc( "Arguments are formatted byte sizes (used/total)", "Memory: %1 / %2" "\xc2\x9c" "Mem: %1 / %2" "\xc2\x9c" "Mem: %1" "\xc2\x9c" "%1",
-                 KFormat().formatByteSize( mUsedApplication*1024),
-                 KFormat().formatByteSize( (mFree+mUsedTotal)*1024 ) );
+      s = i18nc( "Arguments are formatted byte sizes (used/total)", "Memory: %1 / %2", used, total );
+      s += "\xc2\x9c";
+      s += i18nc( "Arguments are formatted byte sizes (used/total) This should be a shorter version of the previous Memory: %1 / %2", "Mem: %1 / %2", used, total );
+      s += "\xc2\x9c";
+      s += i18nc( "Arguments is formatted byte sizes (used) This should be a shorter version of the previous Mem: %1 / %2", "Mem: %1", used );
+      s += "\xc2\x9c";
+      s += used;
       sbMemTotal->setText( s );
       break;
+    }
 
     case 5:
       sFree = answer.toLongLong();
@@ -486,9 +499,13 @@ void TopLevel::setSwapInfo( qlonglong used, qlonglong free, const QString & )
   if ( used == 0 && free == 0 ) // no swap available
     msg = i18n( " No swap space available " );
   else {
-    msg = i18nc( "Arguments are formatted byte sizes (used/total)", "Swap: %1 / %2" "\xc2\x9c" "Swap: %1" "\xc2\x9c" "%1" ,
-                 KFormat().formatByteSize( used*1024 ),
-                 KFormat().formatByteSize( (free+used)*1024) );
+    const auto formattedUsed = KFormat().formatByteSize( used*1024 );
+    const auto formattedTotal = KFormat().formatByteSize( (free+used)*1024);
+    msg = i18nc( "Arguments are formatted byte sizes (used/total)", "Swap: %1 / %2", formattedUsed, formattedTotal );
+    msg += "\xc2\x9c";
+    msg += i18nc( "Arguments is formatted byte sizes (used)", "Swap: %1", formattedUsed );
+    msg += "\xc2\x9c";
+    msg += formattedUsed;
   }
 
   sbSwapTotal->setText( msg );
